import { __assign, __rest } from "tslib";
import React from 'react';
import { enUS } from 'date-fns/locale';
import { Caption } from '../../components/Caption';
import { CaptionLabel } from '../../components/CaptionLabel';
import { Day } from '../../components/Day';
import { DayContent } from '../../components/DayContent';
import { Dropdown } from '../../components/Dropdown';
import { Footer } from '../../components/Footer';
import { Head } from '../../components/Head';
import { IconDropdown } from '../../components/IconDropdown';
import { IconLeft } from '../../components/IconLeft';
import { IconRight } from '../../components/IconRight';
import { Row } from '../../components/Row';
import { WeekNumber } from '../../components/WeekNumber';
import { defaultClassNames } from './defaultClassNames';
import * as formatters from './formatters';
import * as labels from './labels';
import { parseFromToProps } from './utils';
/**
 * The DayPicker Context shares the props passed to DayPicker within internal
 * and custom components. It is used to set the default values and perform
 * one-time calculations required to render the days.
 *
 * Developers may access to this context from the [[useDayPicker]] hook when
 * using custom components.
 */
export var DayPickerContext = React.createContext(undefined);
/**
 * The provider for the [[DayPickerContext]].
 *
 * The context value is set by assigning defaults from the initial DayPicker
 * props.
 * */
export function DayPickerProvider(props) {
    var _a, _b, _c, _d, _e, _f, _g;
    var children = props.children, initialProps = props.initialProps;
    var locale = (_a = initialProps.locale) !== null && _a !== void 0 ? _a : enUS;
    var numberOfMonths = (_b = initialProps.numberOfMonths) !== null && _b !== void 0 ? _b : 1;
    var today = (_c = initialProps.today) !== null && _c !== void 0 ? _c : new Date();
    // Limit navigation
    var _h = parseFromToProps(initialProps), fromDate = _h.fromDate, toDate = _h.toDate;
    // Default caption layout. If calendar navigation is unlimited, it must be
    // always `buttons` – as we cannot display yet infinite options in the dropdown.
    var captionLayout = (_d = initialProps.captionLayout) !== null && _d !== void 0 ? _d : 'buttons';
    if (!fromDate && !toDate)
        captionLayout = 'buttons';
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    var toYear = initialProps.toYear, fromYear = initialProps.fromYear, toMonth = initialProps.toMonth, fromMonth = initialProps.fromMonth, contextProps = __rest(initialProps, ["toYear", "fromYear", "toMonth", "fromMonth"]);
    var context = __assign(__assign({}, contextProps), { captionLayout: captionLayout, fromDate: fromDate, toDate: toDate, today: today, locale: locale, modifierClassNames: (_e = initialProps.modifierClassNames) !== null && _e !== void 0 ? _e : {}, 
        // TODO: Should this be initialProps.modifierPrefix ?? 'rdp-day_'?
        modifierPrefix: 'rdp-day_', modifiers: (_f = initialProps.modifiers) !== null && _f !== void 0 ? _f : {}, numberOfMonths: numberOfMonths, styles: (_g = initialProps.styles) !== null && _g !== void 0 ? _g : {}, classNames: __assign(__assign({}, defaultClassNames), initialProps.classNames), formatters: __assign(__assign({}, formatters), initialProps.formatters), labels: __assign(__assign({}, labels), initialProps.labels), components: __assign({ Caption: Caption, CaptionLabel: CaptionLabel, Day: Day, DayContent: DayContent, Dropdown: Dropdown, Footer: Footer, Head: Head, IconDropdown: IconDropdown, IconRight: IconRight, IconLeft: IconLeft, Row: Row, WeekNumber: WeekNumber }, initialProps.components) });
    return (React.createElement(DayPickerContext.Provider, { value: context }, children));
}
//# sourceMappingURL=DayPickerContext.js.map