import React from 'react';
/** Represents the value of the [[NavigationContext]]. */
export declare type FocusContextValue = {
    /** The day currently focused */
    focusedDay: Date | undefined;
    /** The day that is the target of focus in the day grid (tabIndex = 0) */
    focusTarget: Date | undefined;
    /** Focus the specified day. */
    focus: (day: Date) => void;
    /** Blur the focused day */
    blur: () => void;
    /** Focus the day after the focused day. */
    focusDayAfter: () => void;
    /** Focus the day before the focused day. */
    focusDayBefore: () => void;
    /** Focus the day in the week before the focused day. */
    focusWeekBeforeDay: () => void;
    /** Focus the day in the week after the focused day. */
    focusWeekAfterDay: () => void;
    focusMonthBefore: () => void;
    focusMonthAfter: () => void;
    focusYearBefore: () => void;
    focusYearAfter: () => void;
    focusStartOfWeek: () => void;
    focusEndOfWeek: () => void;
};
/**
 * The Focus context shares details about the focused day for the keyboard navigation.
 *
 * Access this context from the [[useFocus]] hook.
 */
export declare const FocusContext: React.Context<FocusContextValue | undefined>;
/** The provider for the [[FocusContext]]. */
export declare function FocusProvider({ children }: {
    children: React.ReactNode;
}): JSX.Element;
