import { __assign } from "tslib";
import React from 'react';
import { useDayPicker } from '../../contexts/DayPicker';
import { useSelectMultiple } from '../../contexts/SelectMultiple';
import { useSelectRange } from '../../contexts/SelectRange';
import { getCustomModifiers } from './utils/getCustomModifiers';
import { getInternalModifiers } from './utils/getInternalModifiers';
/** The Modifiers context store the modifiers used in DayPicker. To access the value of this context, use [[useModifiers]]. */
export var ModifiersContext = React.createContext(undefined);
/** Provide the value for the [[ModifiersContext]]. */
export function ModifiersProvider(props) {
    var dayPicker = useDayPicker();
    var selectMultiple = useSelectMultiple();
    var selectRange = useSelectRange();
    var internalModifiers = getInternalModifiers(dayPicker, selectMultiple, selectRange);
    var customModifiers = getCustomModifiers(dayPicker);
    var modifiers = __assign(__assign({}, internalModifiers), customModifiers);
    return (React.createElement(ModifiersContext.Provider, { value: modifiers }, props.children));
}
//# sourceMappingURL=ModifiersContext.js.map