import { isDayPickerMultiple } from '../../../types/DayPickerMultiple';
import { isDayPickerRange } from '../../../types/DayPickerRange';
import { InternalModifier } from '../../../types/Modifiers';
import { toMatcherArray } from './toMatcherArray';
/** Return the [[InternalModifiers]] from the DayPicker and select contexts. */
export function getInternalModifiers(dayPicker, selectMultiple, selectRange) {
    var _a;
    var internalModifiers = (_a = {},
        _a[InternalModifier.Selected] = toMatcherArray(dayPicker.selected),
        _a[InternalModifier.Disabled] = toMatcherArray(dayPicker.disabled),
        _a[InternalModifier.Hidden] = toMatcherArray(dayPicker.hidden),
        _a[InternalModifier.Today] = [dayPicker.today],
        _a[InternalModifier.RangeEnd] = [],
        _a[InternalModifier.RangeMiddle] = [],
        _a[InternalModifier.RangeStart] = [],
        _a);
    if (dayPicker.fromDate) {
        internalModifiers.disabled.push({ before: dayPicker.fromDate });
    }
    if (dayPicker.toDate) {
        internalModifiers.disabled.push({ after: dayPicker.toDate });
    }
    if (isDayPickerMultiple(dayPicker)) {
        internalModifiers.disabled = internalModifiers.disabled.concat(selectMultiple.modifiers.disabled);
    }
    else if (isDayPickerRange(dayPicker)) {
        internalModifiers.disabled = internalModifiers.disabled.concat(selectRange.modifiers.disabled);
        internalModifiers.range_start = selectRange.modifiers.range_start;
        internalModifiers.range_middle = selectRange.modifiers.range_middle;
        internalModifiers.range_end = selectRange.modifiers.range_end;
    }
    return internalModifiers;
}
//# sourceMappingURL=getInternalModifiers.js.map