"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Caption = void 0;
var tslib_1 = require("tslib");
var react_1 = (0, tslib_1.__importDefault)(require("react"));
var date_fns_1 = require("date-fns");
var MonthsDropdown_1 = require("../../components/MonthsDropdown");
var Navigation_1 = require("../../components/Navigation");
var YearsDropdown_1 = require("../../components/YearsDropdown");
var DayPicker_1 = require("../../contexts/DayPicker");
var Navigation_2 = require("../../contexts/Navigation");
/**
 * Render the caption of a month, which includes title and navigation buttons.
 * The caption has a different layout when setting the [[DayPickerProps.captionLayout]] prop.
 */
function Caption(props) {
    var _a;
    var displayMonth = props.displayMonth;
    var context = (0, DayPicker_1.useDayPicker)();
    var classNames = context.classNames, numberOfMonths = context.numberOfMonths, disableNavigation = context.disableNavigation, styles = context.styles, captionLayout = context.captionLayout, onMonthChange = context.onMonthChange, dir = context.dir, CaptionLabel = context.components.CaptionLabel;
    var _b = (0, Navigation_2.useNavigation)(), previousMonth = _b.previousMonth, nextMonth = _b.nextMonth, goToMonth = _b.goToMonth, displayMonths = _b.displayMonths;
    var handlePreviousClick = function () {
        if (!previousMonth)
            return;
        goToMonth(previousMonth);
        onMonthChange === null || onMonthChange === void 0 ? void 0 : onMonthChange(previousMonth);
    };
    var handleNextClick = function () {
        if (!nextMonth)
            return;
        goToMonth(nextMonth);
        onMonthChange === null || onMonthChange === void 0 ? void 0 : onMonthChange(nextMonth);
    };
    var handleMonthChange = function (newMonth) {
        goToMonth(newMonth);
        onMonthChange === null || onMonthChange === void 0 ? void 0 : onMonthChange(newMonth);
    };
    var displayIndex = displayMonths.findIndex(function (month) {
        return (0, date_fns_1.isSameMonth)(displayMonth, month);
    });
    var isFirst = displayIndex === 0;
    var isLast = displayIndex === displayMonths.length - 1;
    if (dir === 'rtl') {
        _a = [isFirst, isLast], isLast = _a[0], isFirst = _a[1];
    }
    var hideNext = numberOfMonths > 1 && (isFirst || !isLast);
    var hidePrevious = numberOfMonths > 1 && (isLast || !isFirst);
    var captionLabel = (react_1.default.createElement(CaptionLabel, { id: props.id, displayMonth: displayMonth }));
    var captionContent;
    if (disableNavigation) {
        captionContent = captionLabel;
    }
    else if (captionLayout === 'dropdown') {
        captionContent = (react_1.default.createElement("div", { className: classNames.caption_dropdowns, style: styles.caption_dropdowns },
            react_1.default.createElement("div", { className: classNames.vhidden }, captionLabel),
            react_1.default.createElement(MonthsDropdown_1.MonthsDropdown, { onChange: handleMonthChange, displayMonth: displayMonth }),
            react_1.default.createElement(YearsDropdown_1.YearsDropdown, { onChange: handleMonthChange, displayMonth: displayMonth })));
    }
    else {
        captionContent = (react_1.default.createElement(react_1.default.Fragment, null,
            captionLabel,
            react_1.default.createElement(Navigation_1.Navigation, { displayMonth: displayMonth, hideNext: hideNext, hidePrevious: hidePrevious, nextMonth: nextMonth, previousMonth: previousMonth, onPreviousClick: handlePreviousClick, onNextClick: handleNextClick })));
    }
    return (react_1.default.createElement("div", { className: classNames.caption, style: styles.caption }, captionContent));
}
exports.Caption = Caption;
//# sourceMappingURL=Caption.js.map