"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MonthsDropdown = void 0;
var tslib_1 = require("tslib");
var react_1 = (0, tslib_1.__importDefault)(require("react"));
var date_fns_1 = require("date-fns");
var DayPicker_1 = require("../../contexts/DayPicker");
/**
 * Render the dropdown to navigate between months.
 */
function MonthsDropdown(props) {
    var displayMonth = props.displayMonth;
    var _a = (0, DayPicker_1.useDayPicker)(), fromDate = _a.fromDate, toDate = _a.toDate, styles = _a.styles, locale = _a.locale, formatMonthCaption = _a.formatters.formatMonthCaption, classNames = _a.classNames, Dropdown = _a.components.Dropdown, labelMonthDropdown = _a.labels.labelMonthDropdown;
    if (!fromDate && !toDate) {
        // TODO: use type guards
        return react_1.default.createElement(react_1.default.Fragment, null);
    }
    var dropdownMonths = [];
    if (fromDate && toDate) {
        if ((0, date_fns_1.isSameYear)(fromDate, toDate)) {
            // only display the months included in the range
            for (var month = fromDate.getMonth(); month <= toDate.getMonth(); month++) {
                dropdownMonths.push((0, date_fns_1.setMonth)((0, date_fns_1.startOfMonth)(fromDate), month));
            }
        }
        else {
            // display all the 12 months
            for (var month = 0; month <= 11; month++) {
                var anyDate = new Date(); // any date is OK, we just need the year
                dropdownMonths.push((0, date_fns_1.setMonth)((0, date_fns_1.startOfMonth)(anyDate), month));
            }
        }
    }
    var handleChange = function (e) {
        var newMonth = (0, date_fns_1.setMonth)(new Date(displayMonth), Number(e.target.value));
        props.onChange(newMonth);
    };
    return (react_1.default.createElement(Dropdown, { "aria-label": labelMonthDropdown(), className: classNames.dropdown_month, style: styles.dropdown_month, onChange: handleChange, value: displayMonth.getMonth(), caption: formatMonthCaption(displayMonth, { locale: locale }) }, dropdownMonths.map(function (m) { return (react_1.default.createElement("option", { key: m.getMonth(), value: m.getMonth() }, formatMonthCaption(m, { locale: locale }))); })));
}
exports.MonthsDropdown = MonthsDropdown;
//# sourceMappingURL=MonthsDropdown.js.map