"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getWeeks = void 0;
var date_fns_1 = require("date-fns");
var getOutsideEndDays_1 = require("./getOutsideEndDays");
var getOutsideStartDays_1 = require("./getOutsideStartDays");
/**
 * Return the weeks belonging to the given month.
 */
function getWeeks(month, _a) {
    var locale = _a.locale, fixedWeeks = _a.fixedWeeks;
    var monthStart = (0, date_fns_1.startOfMonth)(month);
    var monthEnd = (0, date_fns_1.endOfMonth)(month);
    var diff = (0, date_fns_1.differenceInCalendarDays)(monthEnd, monthStart);
    var weeks = [];
    var lastWeek = { weekNumber: 0, dates: [] };
    for (var i = 0; i <= diff; i++) {
        var date = (0, date_fns_1.addDays)(monthStart, i);
        var week = (0, date_fns_1.getWeek)(date, { locale: locale });
        if (lastWeek.weekNumber !== week) {
            // Create a new week by adding outside start days
            var startDays = (0, getOutsideStartDays_1.getOutsideStartDays)(date, { locale: locale });
            lastWeek = { weekNumber: week, dates: startDays };
            weeks.push(lastWeek);
        }
        lastWeek.dates.push(date);
    }
    var lastDay = lastWeek.dates[lastWeek.dates.length - 1];
    var endDays = (0, getOutsideEndDays_1.getOutsideEndDays)(lastDay, { locale: locale });
    lastWeek.dates = lastWeek.dates.concat(endDays);
    // Add extra weeks to the month, up to 6 weeks
    if (fixedWeeks) {
        var lastWeekDate = lastWeek.dates[lastWeek.dates.length - 1];
        var weeksInMonth = (0, date_fns_1.getWeeksInMonth)(month, { locale: locale });
        if (weeksInMonth < 6) {
            var diffDays = (0, date_fns_1.differenceInCalendarDays)((0, date_fns_1.addWeeks)(lastWeekDate, 6 - weeksInMonth), lastWeekDate);
            for (var i = 0; i < diffDays; i++) {
                var date = (0, date_fns_1.addDays)(lastWeekDate, i + 1);
                var week = (0, date_fns_1.getWeek)(date, { locale: locale });
                if (lastWeek.weekNumber !== week) {
                    lastWeek = { weekNumber: week, dates: [] };
                    weeks.push(lastWeek);
                }
                lastWeek.dates.push(date);
            }
        }
    }
    return weeks;
}
exports.getWeeks = getWeeks;
//# sourceMappingURL=getWeeks.js.map