"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.YearsDropdown = void 0;
var tslib_1 = require("tslib");
var react_1 = (0, tslib_1.__importDefault)(require("react"));
var date_fns_1 = require("date-fns");
var DayPicker_1 = require("../../contexts/DayPicker");
/**
 * Render a dropdown to change the year. Take in account the `nav.fromDate` and
 * `toDate` from context.
 */
function YearsDropdown(props) {
    var displayMonth = props.displayMonth;
    var _a = (0, DayPicker_1.useDayPicker)(), fromDate = _a.fromDate, toDate = _a.toDate, locale = _a.locale, styles = _a.styles, classNames = _a.classNames, Dropdown = _a.components.Dropdown, formatYearCaption = _a.formatters.formatYearCaption, labelYearDropdown = _a.labels.labelYearDropdown;
    var years = [];
    if (fromDate && toDate) {
        var fromYear = fromDate.getFullYear();
        var toYear = toDate.getFullYear();
        for (var year = fromYear; year <= toYear; year++) {
            years.push((0, date_fns_1.setYear)((0, date_fns_1.startOfYear)(new Date()), year));
        }
    }
    var handleChange = function (e) {
        var newMonth = (0, date_fns_1.setYear)(new Date(displayMonth), Number(e.target.value));
        props.onChange(newMonth);
    };
    return (react_1.default.createElement(Dropdown, { "aria-label": labelYearDropdown(), className: classNames.dropdown_month, style: styles.dropdown_month, onChange: handleChange, value: displayMonth.getFullYear(), caption: formatYearCaption(displayMonth, { locale: locale }) }, years.map(function (year) { return (react_1.default.createElement("option", { key: year.getFullYear(), value: year.getFullYear() }, formatYearCaption(year, { locale: locale }))); })));
}
exports.YearsDropdown = YearsDropdown;
//# sourceMappingURL=YearsDropdown.js.map