"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DayPickerProvider = exports.DayPickerContext = void 0;
var tslib_1 = require("tslib");
var react_1 = (0, tslib_1.__importDefault)(require("react"));
var locale_1 = require("date-fns/locale");
var Caption_1 = require("../../components/Caption");
var CaptionLabel_1 = require("../../components/CaptionLabel");
var Day_1 = require("../../components/Day");
var DayContent_1 = require("../../components/DayContent");
var Dropdown_1 = require("../../components/Dropdown");
var Footer_1 = require("../../components/Footer");
var Head_1 = require("../../components/Head");
var IconDropdown_1 = require("../../components/IconDropdown");
var IconLeft_1 = require("../../components/IconLeft");
var IconRight_1 = require("../../components/IconRight");
var Row_1 = require("../../components/Row");
var WeekNumber_1 = require("../../components/WeekNumber");
var defaultClassNames_1 = require("./defaultClassNames");
var formatters = (0, tslib_1.__importStar)(require("./formatters"));
var labels = (0, tslib_1.__importStar)(require("./labels"));
var utils_1 = require("./utils");
/**
 * The DayPicker Context shares the props passed to DayPicker within the
 * internal components. It is used to set the default values and perform
 * one-time calculations required to render the days.
 *
 * Access this context from the [[useDayPicker]] hook when using custom
 * components.
 */
exports.DayPickerContext = react_1.default.createContext(undefined);
/**
 * The provider for the [[DayPickerContext]]. Set the context value by
 * assigning the defaults from the DayPicker props.
 * */
function DayPickerProvider(props) {
    var _a, _b, _c, _d, _e, _f, _g;
    var children = props.children, initialProps = props.initialProps;
    var locale = (_a = initialProps.locale) !== null && _a !== void 0 ? _a : locale_1.enUS;
    var numberOfMonths = (_b = initialProps.numberOfMonths) !== null && _b !== void 0 ? _b : 1;
    var today = (_c = initialProps.today) !== null && _c !== void 0 ? _c : new Date();
    // Limit navigation
    var _h = (0, utils_1.parseFromToProps)(initialProps), fromDate = _h.fromDate, toDate = _h.toDate;
    // Default caption layout. If calendar navigation is unlimited, it must be
    // always `buttons` – as we cannot display infinite options in the dropdown.
    var captionLayout = (_d = initialProps.captionLayout) !== null && _d !== void 0 ? _d : 'buttons';
    if (!fromDate && !toDate)
        captionLayout = 'buttons';
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    var toYear = initialProps.toYear, fromYear = initialProps.fromYear, toMonth = initialProps.toMonth, fromMonth = initialProps.fromMonth, contextProps = (0, tslib_1.__rest)(initialProps, ["toYear", "fromYear", "toMonth", "fromMonth"]);
    var context = (0, tslib_1.__assign)((0, tslib_1.__assign)({}, contextProps), { captionLayout: captionLayout, fromDate: fromDate, toDate: toDate, today: today, locale: locale, modifierClassNames: (_e = initialProps.modifierClassNames) !== null && _e !== void 0 ? _e : {}, 
        // TODO: Should this be initialProps.modifierPrefix ?? 'rdp-day_'?
        modifierPrefix: 'rdp-day_', modifiers: (_f = initialProps.modifiers) !== null && _f !== void 0 ? _f : {}, numberOfMonths: numberOfMonths, styles: (_g = initialProps.styles) !== null && _g !== void 0 ? _g : {}, classNames: (0, tslib_1.__assign)((0, tslib_1.__assign)({}, defaultClassNames_1.defaultClassNames), initialProps.classNames), formatters: (0, tslib_1.__assign)((0, tslib_1.__assign)({}, formatters), initialProps.formatters), labels: (0, tslib_1.__assign)((0, tslib_1.__assign)({}, labels), initialProps.labels), components: (0, tslib_1.__assign)({ Caption: Caption_1.Caption, CaptionLabel: CaptionLabel_1.CaptionLabel, Day: Day_1.Day, DayContent: DayContent_1.DayContent, Dropdown: Dropdown_1.Dropdown, Footer: Footer_1.Footer, Head: Head_1.Head, IconDropdown: IconDropdown_1.IconDropdown, IconRight: IconRight_1.IconRight, IconLeft: IconLeft_1.IconLeft, Row: Row_1.Row, WeekNumber: WeekNumber_1.WeekNumber }, initialProps.components) });
    return (react_1.default.createElement(exports.DayPickerContext.Provider, { value: context }, children));
}
exports.DayPickerProvider = DayPickerProvider;
//# sourceMappingURL=DayPickerContext.js.map