"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FocusProvider = exports.FocusContext = void 0;
var tslib_1 = require("tslib");
var react_1 = (0, tslib_1.__importDefault)(require("react"));
var date_fns_1 = require("date-fns");
var DayPicker_1 = require("../DayPicker");
var Modifiers_1 = require("../Modifiers");
var useNavigation_1 = require("../Navigation/useNavigation");
var getInitialFocusTarget_1 = require("./getInitialFocusTarget");
/**
 * The Focus context shares details about the focused day for the keyboard navigation.
 *
 * Access this context from the [[useFocus]] hook.
 */
exports.FocusContext = react_1.default.createContext(undefined);
/** The provider for the [[FocusContext]]. */
function FocusProvider(_a) {
    var children = _a.children;
    var _b = react_1.default.useState(), focusedDay = _b[0], setDay = _b[1];
    var _c = (0, useNavigation_1.useNavigation)(), goToMonth = _c.goToMonth, displayMonths = _c.displayMonths;
    var numberOfMonths = (0, DayPicker_1.useDayPicker)().numberOfMonths;
    var modifiersContext = (0, Modifiers_1.useModifiers)();
    var initialFocusTarget = (0, getInitialFocusTarget_1.getInitialFocusTarget)(displayMonths, modifiersContext);
    var _d = react_1.default.useState(), lastFocusedDay = _d[0], setLastFocusedDay = _d[1];
    var isWithinDisplayMonths = function (date) {
        return displayMonths.some(function (displayMonth) { return (0, date_fns_1.isSameMonth)(date, displayMonth); });
    };
    var focusTarget = (focusedDay !== null && focusedDay !== void 0 ? focusedDay : (lastFocusedDay && isWithinDisplayMonths(lastFocusedDay)))
        ? lastFocusedDay
        : initialFocusTarget;
    var blur = function () {
        setLastFocusedDay(focusedDay);
        setDay(undefined);
    };
    var focus = function (date) { return setDay(date); };
    var switchMonth = function (date, offset) {
        if (displayMonths.some(function (m) { return (0, date_fns_1.isSameMonth)(date, m); }))
            return;
        if (offset < 0) {
            goToMonth((0, date_fns_1.addMonths)(date, 1 + offset));
        }
        else {
            goToMonth(date);
        }
    };
    var focusDayBefore = function () {
        if (!focusedDay)
            return;
        var before = (0, date_fns_1.addDays)(focusedDay, -1);
        focus(before);
        switchMonth(before, numberOfMonths * -1);
    };
    var focusDayAfter = function () {
        if (!focusedDay)
            return;
        var after = (0, date_fns_1.addDays)(focusedDay, 1);
        focus(after);
        switchMonth(after, numberOfMonths);
    };
    var focusWeekBeforeDay = function () {
        if (!focusedDay)
            return;
        var up = (0, date_fns_1.addWeeks)(focusedDay, -1);
        focus(up);
        switchMonth(up, numberOfMonths * -1);
    };
    var focusWeekAfterDay = function () {
        if (!focusedDay)
            return;
        var down = (0, date_fns_1.addWeeks)(focusedDay, 1);
        focus(down);
        switchMonth(down, numberOfMonths);
    };
    var focusStartOfWeek = function () {
        if (!focusedDay)
            return;
        var dayToFocus = (0, date_fns_1.startOfWeek)(focusedDay);
        switchMonth(dayToFocus, numberOfMonths);
        focus(dayToFocus);
    };
    var focusEndOfWeek = function () {
        if (!focusedDay)
            return;
        var dayToFocus = (0, date_fns_1.endOfWeek)(focusedDay);
        switchMonth(dayToFocus, numberOfMonths);
        focus(dayToFocus);
    };
    var focusMonthBefore = function () {
        if (!focusedDay)
            return;
        var monthBefore = (0, date_fns_1.addMonths)(focusedDay, -1);
        switchMonth(monthBefore, numberOfMonths);
        focus(monthBefore);
    };
    var focusMonthAfter = function () {
        if (!focusedDay)
            return;
        var monthAfter = (0, date_fns_1.addMonths)(focusedDay, 1);
        switchMonth(monthAfter, numberOfMonths);
        focus(monthAfter);
    };
    var focusYearBefore = function () {
        if (!focusedDay)
            return;
        var yearBefore = (0, date_fns_1.addYears)(focusedDay, -1);
        switchMonth(yearBefore, numberOfMonths);
        focus(yearBefore);
    };
    var focusYearAfter = function () {
        if (!focusedDay)
            return;
        var yearAfter = (0, date_fns_1.addYears)(focusedDay, 1);
        switchMonth(yearAfter, numberOfMonths);
        focus(yearAfter);
    };
    var value = {
        focusedDay: focusedDay,
        focusTarget: focusTarget,
        blur: blur,
        focus: focus,
        focusDayAfter: focusDayAfter,
        focusDayBefore: focusDayBefore,
        focusWeekAfterDay: focusWeekAfterDay,
        focusWeekBeforeDay: focusWeekBeforeDay,
        focusMonthBefore: focusMonthBefore,
        focusMonthAfter: focusMonthAfter,
        focusYearBefore: focusYearBefore,
        focusYearAfter: focusYearAfter,
        focusStartOfWeek: focusStartOfWeek,
        focusEndOfWeek: focusEndOfWeek
    };
    return (react_1.default.createElement(exports.FocusContext.Provider, { value: value }, children));
}
exports.FocusProvider = FocusProvider;
//# sourceMappingURL=FocusContext.js.map