"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ModifiersProvider = exports.ModifiersContext = void 0;
var tslib_1 = require("tslib");
var react_1 = (0, tslib_1.__importDefault)(require("react"));
var DayPicker_1 = require("../../contexts/DayPicker");
var SelectMultiple_1 = require("../../contexts/SelectMultiple");
var SelectRange_1 = require("../../contexts/SelectRange");
var DayPickerMultiple_1 = require("../../types/DayPickerMultiple");
var DayPickerRange_1 = require("../../types/DayPickerRange");
exports.ModifiersContext = react_1.default.createContext(undefined);
function toMatcherArray(modifierFromProp) {
    if (Array.isArray(modifierFromProp)) {
        return modifierFromProp;
    }
    else if (modifierFromProp !== undefined) {
        return [modifierFromProp];
    }
    else {
        return [];
    }
}
/**
 * Parse the modifiers from the props.
 *
 * Internally we want modifiers as an array of matchers – as opposite of the
 * props which can accept also a matcher.
 */
function ModifiersProvider(props) {
    var context = (0, DayPicker_1.useDayPicker)();
    var _a = (0, tslib_1.__assign)({}, context), customModifiers = _a.modifiers, selected = _a.selected, disabled = _a.disabled, hidden = _a.hidden, today = _a.today, fromDate = _a.fromDate, toDate = _a.toDate;
    var multipleSelect = (0, SelectMultiple_1.useSelectMultiple)();
    var rangeSelect = (0, SelectRange_1.useSelectRange)();
    var modifiers = {
        selected: toMatcherArray(selected),
        disabled: toMatcherArray(disabled),
        hidden: toMatcherArray(hidden),
        today: [today],
        range_end: [],
        range_middle: [],
        range_start: []
    };
    Object.entries(customModifiers).forEach(function (_a) {
        var modifier = _a[0], matcher = _a[1];
        modifiers[modifier] = toMatcherArray(matcher);
    });
    if (fromDate) {
        modifiers.disabled.push({ before: fromDate });
    }
    if (toDate) {
        modifiers.disabled.push({ after: toDate });
    }
    if ((0, DayPickerMultiple_1.isDayPickerMultiple)(context)) {
        modifiers.disabled = modifiers.disabled.concat(multipleSelect.modifiers.disabled);
    }
    else if ((0, DayPickerRange_1.isDayPickerRange)(context)) {
        modifiers.disabled = modifiers.disabled.concat(rangeSelect.modifiers.disabled);
        modifiers.range_start = rangeSelect.modifiers.range_start;
        modifiers.range_middle = rangeSelect.modifiers.range_middle;
        modifiers.range_end = rangeSelect.modifiers.range_end;
    }
    return (react_1.default.createElement(exports.ModifiersContext.Provider, { value: modifiers }, props.children));
}
exports.ModifiersProvider = ModifiersProvider;
//# sourceMappingURL=ModifiersContext.js.map