"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NavigationProvider = exports.NavigationContext = void 0;
var tslib_1 = require("tslib");
var react_1 = (0, tslib_1.__importDefault)(require("react"));
var DayPicker_1 = require("../DayPicker");
var useNavigationState_1 = require("./useNavigationState");
var getDisplayMonths_1 = require("./utils/getDisplayMonths");
var getNextMonth_1 = require("./utils/getNextMonth");
var getPreviousMonth_1 = require("./utils/getPreviousMonth");
/**
 * The Navigation context shares details about the months being navigated in DayPicker.
 *
 * Access this context from the [[useNavigation]] hook.
 */
exports.NavigationContext = react_1.default.createContext(undefined);
/** Provides the values for the [[NavigationContext]]. */
function NavigationProvider(props) {
    var context = (0, DayPicker_1.useDayPicker)();
    var _a = (0, useNavigationState_1.useNavigationState)(), month = _a[0], goToMonth = _a[1];
    var displayMonths = (0, getDisplayMonths_1.getDisplayMonths)(month, context);
    var nextMonth = (0, getNextMonth_1.getNextMonth)(month, context);
    var previousMonth = (0, getPreviousMonth_1.getPreviousMonth)(month, context);
    return (react_1.default.createElement(exports.NavigationContext.Provider, { value: {
            month: month,
            displayMonths: displayMonths,
            goToMonth: goToMonth,
            previousMonth: previousMonth,
            nextMonth: nextMonth
        } }, props.children));
}
exports.NavigationProvider = NavigationProvider;
//# sourceMappingURL=NavigationContext.js.map