"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SelectMultipleProviderInternal = exports.SelectMultipleProvider = exports.SelectMultipleContext = void 0;
var tslib_1 = require("tslib");
var react_1 = (0, tslib_1.__importDefault)(require("react"));
var date_fns_1 = require("date-fns");
var DayPickerMultiple_1 = require("../../types/DayPickerMultiple");
/**
 * The SelectMultiple context shares details about the selected days when in
 * multiple selection mode.
 *
 * Access this context from the [[useSelectMultiple]] hook.
 */
exports.SelectMultipleContext = react_1.default.createContext(undefined);
/** Provides the values for the [[SelectMultipleContext]]. */
function SelectMultipleProvider(props) {
    if (!(0, DayPickerMultiple_1.isDayPickerMultiple)(props.initialProps)) {
        var emptyContextValue = {
            selected: undefined,
            modifiers: {
                disabled: []
            }
        };
        return (react_1.default.createElement(exports.SelectMultipleContext.Provider, { value: emptyContextValue }, props.children));
    }
    return (react_1.default.createElement(SelectMultipleProviderInternal, { initialProps: props.initialProps, children: props.children }));
}
exports.SelectMultipleProvider = SelectMultipleProvider;
function SelectMultipleProviderInternal(_a) {
    var initialProps = _a.initialProps, children = _a.children;
    var selected = initialProps.selected;
    var onDayClick = function (day, modifiers, e) {
        var _a, _b;
        (_a = initialProps.onDayClick) === null || _a === void 0 ? void 0 : _a.call(initialProps, day, modifiers, e);
        var isMinSelected = Boolean(initialProps.min &&
            modifiers.selected &&
            selected &&
            selected.length === initialProps.min);
        if (isMinSelected) {
            return;
        }
        var isMaxSelected = Boolean(initialProps.max &&
            !modifiers.selected &&
            selected &&
            selected.length === initialProps.max);
        if (isMaxSelected) {
            return;
        }
        var days = selected ? (0, tslib_1.__spreadArray)([], selected, true) : [];
        if (modifiers.selected) {
            var index = days.findIndex(function (selectedDay) {
                return (0, date_fns_1.isSameDay)(day, selectedDay);
            });
            days.splice(index, 1);
        }
        else {
            days.push(day);
        }
        (_b = initialProps.onSelect) === null || _b === void 0 ? void 0 : _b.call(initialProps, days, day, modifiers, e);
    };
    var modifiers = {
        disabled: []
    };
    if (selected) {
        modifiers.disabled = [
            function disableDay(day) {
                var isMaxSelected = initialProps.max &&
                    selected &&
                    selected.length > initialProps.max - 1;
                var isSelected = selected === null || selected === void 0 ? void 0 : selected.some(function (selectedDay) {
                    return (0, date_fns_1.isSameDay)(selectedDay, day);
                });
                return Boolean(isMaxSelected && !isSelected);
            }
        ];
    }
    var contextValue = { selected: selected, onDayClick: onDayClick, modifiers: modifiers };
    return (react_1.default.createElement(exports.SelectMultipleContext.Provider, { value: contextValue }, children));
}
exports.SelectMultipleProviderInternal = SelectMultipleProviderInternal;
//# sourceMappingURL=SelectMultipleContext.js.map