"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SelectRangeProviderInternal = exports.SelectRangeProvider = exports.SelectRangeContext = void 0;
var tslib_1 = require("tslib");
var react_1 = (0, tslib_1.__importDefault)(require("react"));
var date_fns_1 = require("date-fns");
var DayPickerRange_1 = require("../../types/DayPickerRange");
var addToRange_1 = require("./utils/addToRange");
/**
 * The SelectRange context shares details about the selected days when in
 * range selection mode.
 *
 * Access this context from the [[useSelectRange]] hook.
 */
exports.SelectRangeContext = react_1.default.createContext(undefined);
/** Provides the values for the [[SelectRangeProvider]]. */
function SelectRangeProvider(props) {
    if (!(0, DayPickerRange_1.isDayPickerRange)(props.initialProps)) {
        var emptyContextValue = {
            selected: undefined,
            modifiers: {
                range_start: [],
                range_end: [],
                range_middle: [],
                disabled: []
            }
        };
        return (react_1.default.createElement(exports.SelectRangeContext.Provider, { value: emptyContextValue }, props.children));
    }
    return (react_1.default.createElement(SelectRangeProviderInternal, { initialProps: props.initialProps, children: props.children }));
}
exports.SelectRangeProvider = SelectRangeProvider;
function SelectRangeProviderInternal(_a) {
    var initialProps = _a.initialProps, children = _a.children;
    var selected = initialProps.selected;
    var min = initialProps.min;
    var max = initialProps.max;
    var onDayClick = function (day, modifiers, e) {
        var _a, _b;
        (_a = initialProps.onDayClick) === null || _a === void 0 ? void 0 : _a.call(initialProps, day, modifiers, e);
        var newValue = (0, addToRange_1.addToRange)(day, selected);
        if ((min || max) &&
            selected &&
            (newValue === null || newValue === void 0 ? void 0 : newValue.to) &&
            newValue.from &&
            newValue.from !== newValue.to) {
            var diff = Math.abs((0, date_fns_1.differenceInCalendarDays)(newValue === null || newValue === void 0 ? void 0 : newValue.to, newValue === null || newValue === void 0 ? void 0 : newValue.from));
            if (min && diff < min) {
                return;
            }
            if (max && diff >= max) {
                return;
            }
        }
        (_b = initialProps.onSelect) === null || _b === void 0 ? void 0 : _b.call(initialProps, newValue, day, modifiers, e);
    };
    var modifiers = {
        range_start: [],
        range_end: [],
        range_middle: [],
        disabled: []
    };
    if (selected) {
        if (selected.from) {
            modifiers.range_start = [selected.from];
            if (selected.to) {
                modifiers.range_middle = [
                    {
                        after: selected.from,
                        before: selected.to
                    }
                ];
                if (max || min) {
                    modifiers.disabled = [
                        function (date) {
                            if (max &&
                                selected.to &&
                                selected.from &&
                                (0, date_fns_1.isBefore)(date, selected.from)) {
                                var diff = (0, date_fns_1.differenceInCalendarDays)(selected.to, date);
                                if (diff >= max) {
                                    return true;
                                }
                            }
                            if (max &&
                                selected.to &&
                                selected.from &&
                                (0, date_fns_1.isAfter)(date, selected.to)) {
                                var diff = (0, date_fns_1.differenceInCalendarDays)(date, selected.from);
                                if (diff >= max) {
                                    return true;
                                }
                            }
                            if (min && selected.from && (0, date_fns_1.isBefore)(date, selected.from)) {
                                var diff = (0, date_fns_1.differenceInCalendarDays)(selected.from, date);
                                if (diff < min) {
                                    return true;
                                }
                            }
                            if (min &&
                                selected.to &&
                                selected.from &&
                                (0, date_fns_1.isAfter)(date, selected.to)) {
                                var diff = (0, date_fns_1.differenceInCalendarDays)(date, selected.from);
                                if (diff < min) {
                                    return true;
                                }
                            }
                            return false;
                        }
                    ];
                }
                modifiers.range_end = [selected.to];
            }
            else {
                modifiers.range_end = [selected.from];
            }
        }
    }
    return (react_1.default.createElement(exports.SelectRangeContext.Provider, { value: { selected: selected, onDayClick: onDayClick, modifiers: modifiers } }, children));
}
exports.SelectRangeProviderInternal = SelectRangeProviderInternal;
//# sourceMappingURL=SelectRangeContext.js.map