"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SelectSingleProviderInternal = exports.SelectSingleProvider = exports.SelectSingleContext = void 0;
var tslib_1 = require("tslib");
var react_1 = (0, tslib_1.__importDefault)(require("react"));
var DayPickerSingle_1 = require("../../types/DayPickerSingle");
/**
 * The SelectSingle context shares details about the selected days when in
 * single selection mode.
 *
 * Access this context from the [[useSelectSingle]] hook.
 */
exports.SelectSingleContext = react_1.default.createContext(undefined);
/** Provides the values for the [[SelectSingleProvider]]. */
function SelectSingleProvider(props) {
    if (!(0, DayPickerSingle_1.isDayPickerSingle)(props.initialProps)) {
        var emptyContextValue = {
            selected: undefined
        };
        return (react_1.default.createElement(exports.SelectSingleContext.Provider, { value: emptyContextValue }, props.children));
    }
    return (react_1.default.createElement(SelectSingleProviderInternal, { initialProps: props.initialProps, children: props.children }));
}
exports.SelectSingleProvider = SelectSingleProvider;
function SelectSingleProviderInternal(_a) {
    var initialProps = _a.initialProps, children = _a.children;
    var onDayClick = function (day, dayModifiers, e) {
        var _a, _b;
        if (dayModifiers.selected && !initialProps.required) {
            (_a = initialProps.onSelect) === null || _a === void 0 ? void 0 : _a.call(initialProps, undefined, day, dayModifiers, e);
            return;
        }
        (_b = initialProps.onSelect) === null || _b === void 0 ? void 0 : _b.call(initialProps, day, day, dayModifiers, e);
    };
    var contextValue = {
        selected: initialProps.selected,
        onDayClick: onDayClick
    };
    return (react_1.default.createElement(exports.SelectSingleContext.Provider, { value: contextValue }, children));
}
exports.SelectSingleProviderInternal = SelectSingleProviderInternal;
//# sourceMappingURL=SelectSingleContext.js.map