"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isMatch = void 0;
var date_fns_1 = require("date-fns");
var Matchers_1 = require("../../../types/Matchers");
var isDateInRange_1 = require("./isDateInRange");
/** Returns true if `value` is a Date type. */
function isDateType(value) {
    return (0, date_fns_1.isDate)(value);
}
/** Returns true if `value` is an array of valid dates. */
function isArrayOfDates(value) {
    return Array.isArray(value) && value.every(date_fns_1.isDate);
}
/**
 * Returns `true` whether the day matches against the given matchers.
 */
function isMatch(day, matchers) {
    return matchers.some(function (matcher) {
        if (typeof matcher === 'boolean') {
            return matcher;
        }
        if (isDateType(matcher)) {
            return (0, date_fns_1.isSameDay)(day, matcher);
        }
        if (isArrayOfDates(matcher)) {
            return matcher.includes(day);
        }
        if ((0, Matchers_1.isDateRange)(matcher)) {
            return (0, isDateInRange_1.isDateInRange)(day, matcher);
        }
        if ((0, Matchers_1.isDayOfWeekType)(matcher)) {
            return matcher.dayOfWeek.includes(day.getDay());
        }
        if ((0, Matchers_1.isDateInterval)(matcher)) {
            var isBefore = (0, date_fns_1.differenceInCalendarDays)(matcher.before, day) > 0;
            var isAfter = (0, date_fns_1.differenceInCalendarDays)(day, matcher.after) > 0;
            return isBefore && isAfter;
        }
        if ((0, Matchers_1.isDateAfterType)(matcher)) {
            return (0, date_fns_1.differenceInCalendarDays)(day, matcher.after) > 0;
        }
        if ((0, Matchers_1.isDateBeforeType)(matcher)) {
            return (0, date_fns_1.differenceInCalendarDays)(matcher.before, day) > 0;
        }
        if (typeof matcher === 'function') {
            return matcher(day);
        }
        return false;
    });
}
exports.isMatch = isMatch;
//# sourceMappingURL=isMatch.js.map